==> numbers-parser-2.3.0.tar.gz: numbers-parser-2.3.0/src/numbers_parser/functionmap.py <==
FUNCTION_MAP = {
    1: "ABS",
    2: "ACCRINT",
    3: "ACCRINTM",
    4: "ACOS",
    5: "ACOSH",
    6: "ADDRESS",
    7: "AND",
    7: "AND",
    8: "AREAS",
    9: "ASIN",
    10: "ASINH",
    11: "ATAN",
    12: "ATAN2",
    13: "ATANH",
    14: "AVEDEV",
    15: "AVERAGE",
    16: "AVERAGEA",
    17: "CEILING",
    18: "CHAR",
    19: "CHOOSE",
    20: "CLEAN",
    21: "CODE",
    22: "COLUMN",
    23: "COLUMNS",
    24: "COMBIN",
    25: "CONCATENATE",
    26: "CONFIDENCE",
    27: "CORREL",
    28: "COS",
    29: "COSH",
    30: "COUNT",
    31: "COUNTA",
    32: "COUNTBLANK",
    33: "COUNTIF",
    34: "COUPDAYBS",
    35: "COUPDAYS",
    36: "COUPDAYSNC",
    37: "COUPNUM",
    38: "COVAR",
    39: "DATE",
    40: "DATEDIF",
    41: "DAY",
    42: "DB",
    43: "DDB",
    44: "DEGREES",
    45: "DISC",
    46: "DOLLAR",
    47: "EDATE",
    48: "EVEN",
    49: "EXACT",
    50: "EXP",
    51: "FACT",
    52: "FALSE",
    53: "FIND",
    54: "FIXED",
    55: "FLOOR",
    56: "FORECAST",
    57: "FV",
    58: "GCD",
    59: "HLOOKUP",
    60: "HOUR",
    62: "IF",
    63: "INDEX",
    64: "INDIRECT",
    65: "INT",
    66: "INTERCEPT",
    67: "PMT",
    68: "IRR",
    69: "ISBLANK",
    70: "ISERROR",
    71: "ISEVEN",
    72: "ISODD",
    73: "ISPMT",
    74: "LARGE",
    75: "LCM",
    76: "LEFT",
    77: "LEN",
    78: "LN",
    79: "LOG",
    80: "LOG10",
    81: "LOOKUP",
    82: "LOWER",
    83: "MATCH",
    84: "MAX",
    85: "MAXA",
    86: "MEDIAN",
    87: "MID",
    88: "MIN",
    89: "MINA",
    90: "MINUTE",
    91: "MIRR",
    92: "MOD",
    93: "MODE",
    94: "MONTH",
    95: "MROUND",
    96: "NOT",
    97: "NOW",
    98: "NPER",
    99: "NPV",
    100: "ODD",
    101: "OFFSET",
    102: "OR",
    103: "PERCENTILE",
    104: "PI",
    105: "PMT",
    106: "POISSONDIST",
    107: "POWER",
    108: "PPMT",
    109: "PRICE",
    110: "PRICEDISC",
    111: "PRICEMAT",
    112: "PROB",
    113: "PRODUCT",
    114: "PROPER",
    115: "PV",
    116: "QUOTIENT",
    117: "RADIANS",
    118: "RAND",
    119: "RANDBETWEEN",
    120: "RANK",
    121: "RATE",
    122: "REPLACE",
    123: "REPT",
    124: "RIGHT",
    125: "ROMAN",
    126: "ROUND",
    127: "ROUNDDOWN",
    128: "ROUNDUP",
    129: "ROW",
    130: "ROWS",
    131: "SEARCH",
    132: "SECOND",
    133: "SIGN",
    134: "SIN",
    135: "SINH",
    136: "SLN",
    137: "SLOPE",
    138: "SMALL",
    139: "SQRT",
    140: "STDEV",
    141: "STDEVA",
    142: "STDEVP",
    143: "STDEVPA",
    144: "SUBSTITUTE",
    145: "SUMIF",
    146: "SUMPRODUCT",
    147: "SUMSQ",
    148: "SYD",
    149: "T",
    150: "TAN",
    151: "TANH",
    152: "TIME",
    153: "TIMEVALUE",
    154: "TODAY",
    155: "TRIM",
    156: "TRUE",
    157: "TRUNC",
    158: "UPPER",
    159: "VALUE",
    160: "VAR",
    161: "VARA",
    162: "VARP",
    163: "VARPA",
    164: "VDB",
    165: "VLOOKUP",
    166: "WEEKDAY",
    167: "YEAR",
    168: "SUM",
    185: "EFFECT",
    186: "NOMINAL",
    187: "NORMDIST",
    188: "NORMSDIST",
    189: "NORMINV",
    190: "NORMSINV",
    191: "YIELD",
    192: "YIELDDISC",
    193: "YIELDMAT",
    194: "BONDDURATION",
    195: "BONDMDURATION",
    196: "ERF",
    197: "ERFC",
    198: "STANDARDIZE",
    199: "INTRATE",
    200: "RECEIVED",
    201: "CUMIPMT",
    202: "CUMPRINC",
    203: "EOMONTH",
    204: "WORKDAY",
    205: "MONTHNAME",
    206: "WEEKNUM",
    207: "DUR2HOURS",
    208: "DUR2MINUTES",
    209: "DUR2SECONDS",
    210: "DUR2DAYS",
    211: "DUR2WEEKS",
    212: "DURATION",
    213: "EXPONDIST",
    214: "YEARFRAC",
    215: "ZTEST",
    216: "SUMX2MY2",
    217: "SUMX2PY2",
    218: "SUMXMY2",
    219: "SQRTPI",
    220: "TRANSPOSE",
    221: "DEVSQ",
    222: "FREQUENCY",
    223: "DELTA",
    224: "FACTDOUBLE",
    225: "GESTEP",
    226: "PERCENTRANK",
    227: "GAMMALN",
    228: "DATEVALUE",
    229: "GAMMADIST",
    230: "GAMMAINV",
    231: "SUMIFS",
    232: "AVERAGEIFS",
    233: "COUNTIFS",
    234: "AVERAGEIF",
    235: "IFERROR",
    236: "DAYNAME",
    237: "BESSELJ",
    238: "BESSELY",
    239: "LOGNORMDIST",
    240: "LOGNORMINV",
    241: "TDIST",
    242: "BINOMDIST",
    243: "NEGBINOMDIST",
    244: "FDIST",
    245: "PERMUT",
    246: "CHIDIST",
    247: "CHITEST",
    248: "TTEST",
    249: "QUARTILE",
    250: "MULTINOMIAL",
    251: "CRITBINOM",
    252: "BASETONUM",
    253: "NUMTOBASE",
    254: "TINV",
    255: "CONVERT",
    256: "CHINV",
    257: "FINV",
    258: "BETADIST",
    259: "BETAINV",
    260: "NETWORKDAYS",
    261: "DAYS360",
    262: "HARMEAN",
    263: "GEOMEAN",
    264: "DEC2HEX",
    265: "DEC2BIN",
    266: "DEC2OCT",
    267: "BIN2HEX",
    268: "BIN2DEC",
    269: "BIN2OCT",
    270: "OCT2BIN",
    271: "OCT2DEC",
    272: "OCT2HEX",
    273: "HEX2BIN",
    274: "HEX2DEC",
    275: "HEX2OCT",
    276: "LINEST",
    277: "DUR2MILLISECONDS",
    278: "STRIPDURATION",
    280: "INTERSECT.RANGES",
    285: "UNION.RANGES",
    286: "SERIESSUM",
    287: "POLYNOMIAL",
    288: "WEIBULL",
    304: "ISNUMBER",
    305: "ISTEXT",
}

==> numbers-parser-2.3.9.tar.gz: numbers-parser-2.3.9/src/numbers_parser/functionmap.py <==
FUNCTION_MAP = {
    1: "ABS",
    2: "ACCRINT",
    3: "ACCRINTM",
    4: "ACOS",
    5: "ACOSH",
    6: "ADDRESS",
    7: "AND",
    8: "AREAS",
    9: "ASIN",
    10: "ASINH",
    11: "ATAN",
    12: "ATAN2",
    13: "ATANH",
    14: "AVEDEV",
    15: "AVERAGE",
    16: "AVERAGEA",
    17: "CEILING",
    18: "CHAR",
    19: "CHOOSE",
    20: "CLEAN",
    21: "CODE",
    22: "COLUMN",
    23: "COLUMNS",
    24: "COMBIN",
    25: "CONCATENATE",
    26: "CONFIDENCE",
    27: "CORREL",
    28: "COS",
    29: "COSH",
    30: "COUNT",
    31: "COUNTA",
    32: "COUNTBLANK",
    33: "COUNTIF",
    34: "COUPDAYBS",
    35: "COUPDAYS",
    36: "COUPDAYSNC",
    37: "COUPNUM",
    38: "COVAR",
    39: "DATE",
    40: "DATEDIF",
    41: "DAY",
    42: "DB",
    43: "DDB",
    44: "DEGREES",
    45: "DISC",
    46: "DOLLAR",
    47: "EDATE",
    48: "EVEN",
    49: "EXACT",
    50: "EXP",
    51: "FACT",
    52: "FALSE",
    53: "FIND",
    54: "FIXED",
    55: "FLOOR",
    56: "FORECAST",
    57: "FV",
    58: "GCD",
    59: "HLOOKUP",
    60: "HOUR",
    61: "HYPERLINK",
    62: "IF",
    63: "INDEX",
    64: "INDIRECT",
    65: "INT",
    66: "INTERCEPT",
    67: "IPMT",
    68: "IRR",
    69: "ISBLANK",
    70: "ISERROR",
    71: "ISEVEN",
    72: "ISODD",
    73: "ISPMT",
    74: "LARGE",
    75: "LCM",
    76: "LEFT",
    77: "LEN",
    78: "LN",
    79: "LOG",
    80: "LOG10",
    81: "LOOKUP",
    82: "LOWER",
    83: "MATCH",
    84: "MAX",
    85: "MAXA",
    86: "MEDIAN",
    87: "MID",
    88: "MIN",
    89: "MINA",
    90: "MINUTE",
    91: "MIRR",
    92: "MOD",
    93: "MODE",
    94: "MONTH",
    95: "MROUND",
    96: "NOT",
    97: "NOW",
    98: "NPER",
    99: "NPV",
    100: "ODD",
    101: "OFFSET",
    102: "OR",
    103: "PERCENTILE",
    104: "PI",
    105: "PMT",
    106: "POISSON",
    107: "POWER",
    108: "PPMT",
    109: "PRICE",
    110: "PRICEDISC",
    111: "PRICEMAT",
    112: "PROB",
    113: "PRODUCT",
    114: "PROPER",
    115: "PV",
    116: "QUOTIENT",
    117: "RADIANS",
    118: "RAND",
    119: "RANDBETWEEN",
    120: "RANK",
    121: "RATE",
    122: "REPLACE",
    123: "REPT",
    124: "RIGHT",
    125: "ROMAN",
    126: "ROUND",
    127: "ROUNDDOWN",
    128: "ROUNDUP",
    129: "ROW",
    130: "ROWS",
    131: "SEARCH",
    132: "SECOND",
    133: "SIGN",
    134: "SIN",
    135: "SINH",
    136: "SLN",
    137: "SLOPE",
    138: "SMALL",
    139: "SQRT",
    140: "STDEV",
    141: "STDEVA",
    142: "STDEVP",
    143: "STDEVPA",
    144: "SUBSTITUTE",
    145: "SUMIF",
    146: "SUMPRODUCT",
    147: "SUMSQ",
    148: "SYD",
    149: "T",
    150: "TAN",
    151: "TANH",
    152: "TIME",
    153: "TIMEVALUE",
    154: "TODAY",
    155: "TRIM",
    156: "TRUE",
    157: "TRUNC",
    158: "UPPER",
    159: "VALUE",
    160: "VAR",
    161: "VARA",
    162: "VARP",
    163: "VARPA",
    164: "VDB",
    165: "VLOOKUP",
    166: "WEEKDAY",
    167: "YEAR",
    168: "SUM",
    185: "EFFECT",
    186: "NOMINAL",
    187: "NORMDIST",
    188: "NORMSDIST",
    189: "NORMINV",
    190: "NORMSINV",
    191: "YIELD",
    192: "YIELDDISC",
    193: "YIELDMAT",
    194: "BONDDURATION",
    195: "BONDMDURATION",
    196: "ERF",
    197: "ERFC",
    198: "STANDARDIZE",
    199: "INTRATE",
    200: "RECEIVED",
    201: "CUMIPMT",
    202: "CUMPRINC",
    203: "EOMONTH",
    204: "WORKDAY",
    205: "MONTHNAME",
    206: "WEEKNUM",
    207: "DUR2HOURS",
    208: "DUR2MINUTES",
    209: "DUR2SECONDS",
    210: "DUR2DAYS",
    211: "DUR2WEEKS",
    212: "DURATION",
    213: "EXPONDIST",
    214: "YEARFRAC",
    215: "ZTEST",
    216: "SUMX2MY2",
    217: "SUMX2PY2",
    218: "SUMXMY2",
    219: "SQRTPI",
    220: "TRANSPOSE",
    221: "DEVSQ",
    222: "FREQUENCY",
    223: "DELTA",
    224: "FACTDOUBLE",
    225: "GESTEP",
    226: "PERCENTRANK",
    227: "GAMMALN",
    228: "DATEVALUE",
    229: "GAMMADIST",
    230: "GAMMAINV",
    231: "SUMIFS",
    232: "AVERAGEIFS",
    233: "COUNTIFS",
    234: "AVERAGEIF",
    235: "IFERROR",
    236: "DAYNAME",
    237: "BESSELJ",
    238: "BESSELY",
    239: "LOGNORMDIST",
    240: "LOGINV",
    241: "TDIST",
    242: "BINOMDIST",
    243: "NEGBINOMDIST",
    244: "FDIST",
    245: "PERMUT",
    246: "CHIDIST",
    247: "CHITEST",
    248: "TTEST",
    249: "QUARTILE",
    250: "MULTINOMIAL",
    251: "CRITBINOM",
    252: "BASETONUM",
    253: "NUMTOBASE",
    254: "TINV",
    255: "CONVERT",
    256: "CHIINV",
    257: "FINV",
    258: "BETADIST",
    259: "BETAINV",
    260: "NETWORKDAYS",
    261: "DAYS360",
    262: "HARMEAN",
    263: "GEOMEAN",
    264: "DEC2HEX",
    265: "DEC2BIN",
    266: "DEC2OCT",
    267: "BIN2HEX",
    268: "BIN2DEC",
    269: "BIN2OCT",
    270: "OCT2BIN",
    271: "OCT2DEC",
    272: "OCT2HEX",
    273: "HEX2BIN",
    274: "HEX2DEC",
    275: "HEX2OCT",
    276: "LINEST",
    277: "DUR2MILLISECONDS",
    278: "STRIPDURATION",
    280: "INTERSECT.RANGES",
    285: "UNION.RANGES",
    286: "SERIESSUM",
    287: "POLYNOMIAL",
    288: "WEIBULL",
    298: "STOCK",
    299: "STOCKH",
    300: "CURRENCY",
    301: "CURRENCYH",
    302: "CURRENCYCONVERT",
    303: "CURRENCYCODE",
    304: "ISNUMBER",
    305: "ISTEXT",
    306: "ISDATE",
    309: "MAXIFS",
    310: "MINIFS",
    311: "XIRR",
    312: "XNPV",
    313: "IFS",
    314: "XLOOKUP",
    315: "XMATCH",
    316: "SUBTOTAL",
    317: "COUNTMATCHES",
    318: "TEXTBEFORE",
    319: "TEXTBETWEEN",
    320: "TEXTAFTER",
    321: "REGEX",
    323: "FORMULATEXT",
    325: "GETPIVOTDATA",
}
